diff src/buffer.c @ 107583:f35e7896a0fe

Retrospective commit. These are the original changes made by Kenichi Handa on the old pre Emacs 22 emacs-bidi branch.
author Eli Zaretskii <eliz@gnu.org>
date Thu, 31 Dec 2009 14:44:59 -0500
parents f2cea199b0c4
children e0df0337f248
line wrap: on
line diff
--- a/src/buffer.c	Wed Dec 30 21:14:46 2009 -0500
+++ b/src/buffer.c	Thu Dec 31 14:44:59 2009 -0500
@@ -5186,7 +5186,8 @@
   buffer_defaults.truncate_lines = Qnil;
   buffer_defaults.word_wrap = Qnil;
   buffer_defaults.ctl_arrow = Qt;
-  buffer_defaults.direction_reversed = Qnil;
+  buffer_defaults.enable_bidi_display = Qnil;
+  buffer_defaults.orientation_reversed = Qnil;
   buffer_defaults.cursor_type = Qt;
   buffer_defaults.extra_line_spacing = Qnil;
   buffer_defaults.cursor_in_non_selected_windows = Qt;
@@ -5271,7 +5272,8 @@
   XSETFASTINT (buffer_local_flags.syntax_table, idx); ++idx;
   XSETFASTINT (buffer_local_flags.cache_long_line_scans, idx); ++idx;
   XSETFASTINT (buffer_local_flags.category_table, idx); ++idx;
-  XSETFASTINT (buffer_local_flags.direction_reversed, idx); ++idx;
+  XSETFASTINT (buffer_local_flags.enable_bidi_display, idx); ++idx;
+  XSETFASTINT (buffer_local_flags.orientation_reversed, idx); ++idx;
   XSETFASTINT (buffer_local_flags.buffer_file_coding_system, idx);
   /* Make this one a permanent local.  */
   buffer_permanent_local_flags[idx++] = 1;
@@ -5528,10 +5530,15 @@
 		     doc: /* Default value of `ctl-arrow' for buffers that do not override it.
 This is the same as (default-value 'ctl-arrow).  */);
 
-  DEFVAR_LISP_NOPRO ("default-direction-reversed",
-                     &buffer_defaults.direction_reversed,
-                     doc: /* Default value of `direction-reversed' for buffers that do not override it.
-This is the same as (default-value 'direction-reversed).  */);
+    DEFVAR_LISP_NOPRO ("default-enable-bidi-display",
+		      &buffer_defaults.enable_bidi_display,
+		      doc: /* *Default value of `enable-bidi-display' for buffers not overriding it.
+This is the same as (default-value 'enable-bidi-display).  */);
+
+  DEFVAR_LISP_NOPRO ("default-orientation-reversed",
+		     &buffer_defaults.orientation_reversed,
+		     doc: /* *Default value of `orientation-reversed' for buffers that do not override it.
+This is the same as (default-value 'orientation-reversed).  */);
 
   DEFVAR_LISP_NOPRO ("default-enable-multibyte-characters",
                      &buffer_defaults.enable_multibyte_characters,
@@ -5789,11 +5796,17 @@
 
 This variable is never applied to a way of decoding a file while reading it.  */);
 
-  DEFVAR_PER_BUFFER ("direction-reversed", &current_buffer->direction_reversed,
-		     Qnil,
-		     doc: /* *Non-nil means lines in the buffer are displayed right to left.  */);
-
-  DEFVAR_PER_BUFFER ("truncate-lines", &current_buffer->truncate_lines, Qnil,
+  DEFVAR_PER_BUFFER ("orientation-reversed",
+		     &current_buffer->orientation_reversed, Qnil,
+		     doc: /* Non-nil means set beginning of lines at the right end of the window.
+See also the variable `enable-bidi-display'.  */);
+
+  DEFVAR_PER_BUFFER ("enable-bidi-display",
+		     &current_buffer->enable_bidi_display, Qnil,
+		     doc: /*Non-nil means display bidi text in correct visual order.
+See also the variable `orientation-reversed'.  */);
+
+ DEFVAR_PER_BUFFER ("truncate-lines", &current_buffer->truncate_lines, Qnil,
 		     doc: /* *Non-nil means do not display continuation lines.
 Instead, give each line of text just one screen line.